.. currentmodule:: sardana.pool

.. _sardana-2d-overview:

=======================
2D channel overview
=======================

.. todo:: document 2D experiment channel overview

.. seealso:: 
    
    :ref:`sardana-2d-api`
        the 2D experiment channel :term:`API` 
    
    :class:`~sardana.tango.pool.TwoDExpChannel.TwoDExpChannel`
        the 2D experiment channel tango device :term:`API`
